@@ -3,7 +3,11 @@ map_frame.py
 
 Mapview frame class for PyGPSClient application.
 
-This handles a frame containing a location map downloaded via a MapQuest API.
+This handles a frame containing a location map which can be either:
+
+ - one or more fixed offline maps based on user-provided georeferenced
+   images e.g. geoTIFF (defaults to Mercator world image).
+ - dynamic online map or satellite image accessed via a MapQuest API.
 
 NOTE: The free MapQuest API key is subject to a limit of 15,000
 transactions / month, or roughly 500 / day, so the map updates are only
@@ -13,7 +17,7 @@ real time navigation.
 Created on 13 Sep 2020
 
 :author: semuadmin
-:copyright: SEMU Consulting © 2020
+:copyright: 2020 SEMU Consulting
 :license: BSD 3-Clause
 """
 
@@ -21,25 +25,39 @@ from http.client import responses
 from io import BytesIO
 from os import getenv
 from time import time
-from tkinter import NW, Canvas, E, Frame, N, S, W, font
+from tkinter import CENTER, NW, Canvas, E, Frame, N, S, W, font
 
-from PIL import Image, ImageTk
+from PIL import Image, ImageTk, UnidentifiedImageError
 from requests import ConnectionError as ConnError
 from requests import ConnectTimeout, RequestException, get
 
-from pygpsclient.globals import BGCOL, ICON_POS, IMG_WORLD, WIDGETU2
+from pygpsclient.globals import BGCOL, ICON_POS, IMG_WORLD, IMG_WORLD_CALIB, WIDGETU2
 from pygpsclient.mapquest import (
     MAP_UPDATE_INTERVAL,
     MAPQTIMEOUT,
     MAPURL,
+    MARKERURL,
     MAX_ZOOM,
     MIN_UPDATE_INTERVAL,
     MIN_ZOOM,
 )
-from pygpsclient.strings import NOWEBMAPCONN, NOWEBMAPFIX, NOWEBMAPHTTP, NOWEBMAPKEY
+from pygpsclient.strings import (
+    MAPCONFIGERR,
+    MAPOPENERR,
+    NOCONN,
+    NOWEBMAPCONN,
+    NOWEBMAPFIX,
+    NOWEBMAPHTTP,
+    NOWEBMAPKEY,
+    OUTOFBOUNDS,
+)
 
 ZOOMCOL = "red"
 ZOOMEND = "lightgray"
+WORLD = "world"
+CUSTOM = "custom"
+MAP = "map"
+SAT = "sat"
 
 
 class MapviewFrame(Frame):
@@ -72,6 +90,8 @@ class MapviewFrame(Frame):
         self._resize_font_width = self._resize_font.measure("+")
         self._zoom = int((MAX_ZOOM - MIN_ZOOM) / 2)
         self._lastmaptype = ""
+        self._lastmappath = ""
+        self._mapimage = None
         self._body()
         self._attach_events()
 
@@ -126,6 +146,7 @@ class MapviewFrame(Frame):
         w, h = self.width, self.height
         fw, fh = self._resize_font_width, self._resize_font_height
         # zoom out (-) if not already at min
+        zinc = 0
         if w > event.x > w - 2 - fw and h > event.y > h - fh:
             if self._zoom > MIN_ZOOM:
                 zinc = -1 if event.num == 1 else MIN_ZOOM - self._zoom
@@ -162,56 +183,96 @@ class MapviewFrame(Frame):
             self._disp_error(NOWEBMAPFIX)
             return
 
-        maptype = self.__app.frm_settings.config.get("maptype_s", "world")
-        if maptype == "world":
-            self._draw_static_map(lat, lon)
+        maptype = self.__app.frm_settings.config.get("maptype_s", WORLD)
+        if maptype in (WORLD, CUSTOM):
+            self._draw_offline_map(lat, lon, maptype)
         else:
-            if hacc is None or hacc == "":
-                hacc = 0
-            self._draw_web_map(lat, lon, hacc, maptype)
+            self._draw_online_map(lat, lon, maptype, hacc)
 
-    def _draw_static_map(self, lat: float, lon: float):
+    def _draw_offline_map(
+        self,
+        lat: float,
+        lon: float,
+        maptype: str = WORLD,
+    ):
         """
-        Draw fixed scale Mercator world map
+        Draw fixed offline map using optional user-provided georeferenced
+        image path(s) and calibration bounding box(es).
+
+        Defaults to Mercator world image with bounding box [90, -180, -90, 180]
+        if location is not within bounds of any custom map.
 
         :param float lat: latitude
         :param float lon: longitude
+        :param str maptype: "world" or "custom"
         """
         # pylint: disable=no-member
 
-        OFFSET_X = 0
-        OFFSET_Y = 0
-
-        self._lastmaptype = "world"
         w, h = self.width, self.height
-        self._can_mapview.delete("all")
-        self._img = ImageTk.PhotoImage(Image.open(IMG_WORLD).resize((w, h)))
-        self._marker = ImageTk.PhotoImage(Image.open(ICON_POS))
-        self._can_mapview.create_image(0, 0, image=self._img, anchor=NW)
-        x = (w / 2) + int((lon * (w / 360))) + OFFSET_X
-        y = (h / 2) - int((lat * (h / 180))) + OFFSET_Y
-        self._can_mapview.create_image(x, y, image=self._marker, anchor=S)
+        self._lastmaptype = maptype
+        bounds = IMG_WORLD_CALIB
+        err = ""
 
-    def _draw_web_map(self, lat: float, lon: float, hacc: float, maptype: str = "map"):
+        if maptype == CUSTOM:
+            err = OUTOFBOUNDS
+            # usermaps = self.__app.frm_settings.config.get("usermaps_l", [])
+            usermaps = self.__app.saved_config.get("usermaps_l", [])
+            for mp in usermaps:
+                try:
+                    mpath, bounds = mp
+                    if (bounds[0] > lat > bounds[2]) and (bounds[1] < lon < bounds[3]):
+                        if self._lastmappath != mpath:
+                            self._mapimage = Image.open(mpath)
+                            self._lastmappath = mpath
+                        err = ""
+                        break
+                except (ValueError, IndexError):
+                    err = MAPCONFIGERR
+                    break
+                except (FileNotFoundError, UnidentifiedImageError):
+                    err = MAPOPENERR.format(mpath.split("/")[-1])
+                    break
+
+        if maptype == WORLD or err != "":
+            if self._lastmappath != IMG_WORLD:
+                self._mapimage = Image.open(IMG_WORLD)
+                self._lastmappath = IMG_WORLD
+            bounds = IMG_WORLD_CALIB
+
+        self._can_mapview.delete("all")
+        self._img = ImageTk.PhotoImage(self._mapimage.resize((w, h)))
+        self._can_mapview.create_image(0, 0, image=self._img, anchor=NW)
+        plon = w / (bounds[3] - bounds[1])  # x pixels per degree lon
+        plat = h / (bounds[0] - bounds[2])  # y pixels per degree lat
+        x = (lon - bounds[1]) * plon
+        y = (bounds[0] - lat) * plat
+        self._marker = ImageTk.PhotoImage(Image.open(ICON_POS))
+        self._can_mapview.create_image(x, y, image=self._marker, anchor=CENTER)
+        if err != "":
+            self._can_mapview.create_text(w / 2, h / 2, text=err, fill="orange")
+
+    def _draw_online_map(
+        self, lat: float, lon: float, maptype: str = MAP, hacc: float = 0
+    ):
         """
-        Draw scalable web map via MapQuest API
+        Draw scalable web map or satellite image via online MapQuest API.
 
         :param float lat: latitude
         :param float lon: longitude
-        :param float hacc: horizontal accuracy
         :param str maptype: "map" or "sat"
+        :param float hacc: horizontal accuracy
         """
 
-        sc = "NO CONNECTION"
+        sc = NOCONN
         msg = ""
+        hacc = hacc if isinstance(hacc, (float, int)) else 0
 
         if maptype != self._lastmaptype:
             self._lastmaptype = maptype
             self.reset_map_refresh()
 
         mqapikey = self.__app.frm_settings.config.get(
-            "mqapikey_s",
-            self.__app.frm_settings.config.get("mqapikey", getenv("mqapikey", "")),
+            "mqapikey_s", getenv("MQAPIKEY", "")
         )
         if mqapikey == "":
             self._disp_error(NOWEBMAPKEY)
@@ -325,6 +386,7 @@ class MapviewFrame(Frame):
             mqapikey,
             lat,
             lon,
+            MARKERURL,
             zoom,
             w,
             h,
