@@ -8,14 +8,19 @@ This handles the menu bar.
 Created on 12 Sep 2020
 
 :author: semuadmin
-:copyright: SEMU Consulting © 2020
+:copyright: 2020 SEMU Consulting
 :license: BSD 3-Clause
 """
 
 from tkinter import Menu
 
-from pygpsclient.globals import DLGTABOUT, DLGTGPX, DLGTNTRIP, DLGTSPARTN, DLGTUBX
 from pygpsclient.strings import (
+    DLGTABOUT,
+    DLGTGPX,
+    DLGTIMPORTMAP,
+    DLGTNTRIP,
+    DLGTSPARTN,
+    DLGTUBX,
     MENUABOUT,
     MENUEXIT,
     MENUFILE,
@@ -28,7 +33,7 @@ from pygpsclient.strings import (
 )
 from pygpsclient.widget_state import MENU, widget_state
 
-DIALOGS = (DLGTUBX, DLGTNTRIP, DLGTSPARTN, DLGTGPX)
+DIALOGS = (DLGTUBX, DLGTNTRIP, DLGTSPARTN, DLGTGPX, DLGTIMPORTMAP)
 
 
 class MenuBar(Menu):
