@@ -25,14 +25,18 @@ from pygpsclient.helpers import (
     get_mp_info,
     haversine,
     hsv2rgb,
+    isot2dt,
     kmph2ms,
     knots2ms,
+    lanip,
     m2ft,
     ms2kmph,
     ms2knots,
     ms2mph,
+    ned2vector,
     parse_rxmspartnkey,
     pos2iso6709,
+    publicip,
     secs2unit,
     snr2col,
     str2rgb,
@@ -41,12 +45,9 @@ from pygpsclient.helpers import (
     val2sphp,
     validURL,
     wnotow2date,
-    ned2vector,
-    publicip,
-    lanip,
 )
 from pygpsclient.mapquest import mapq_compress, mapq_decompress
-from pygpsclient.widget_state import widget_state, MENU, VISIBLE, DEFAULT, FRAME
+from pygpsclient.widget_state import DEFAULT, FRAME, MENU, VISIBLE, widget_state
 
 
 class StaticTest(unittest.TestCase):
@@ -329,7 +330,7 @@ class StaticTest(unittest.TestCase):
         encoded = mapq_compress(points, PREC)
         self.assertEqual(encoded, "gvw{dBjwmdCvkdnArqpAvho[fciQnibk@w`f_@wibiCf}dH")
         pnts = mapq_decompress(encoded, PREC)
-        print(pnts)
+        # print(pnts)
         for i, pnt in enumerate(pnts):
             self.assertAlmostEqual(pnt, points[i], PREC)
 
@@ -346,8 +347,8 @@ class StaticTest(unittest.TestCase):
         ]
         for i, b in enumerate(blist):
             res = bytes2unit(b)
-            print(res)
-            # self.assertEqual(res, bres[i])
+            # print(res)
+            self.assertEqual(res, bres[i])
 
     def testsecs2unit(self):  # test secs2unit
         slist = [123, 5365, 97467383, 103, 15234, 3]
@@ -456,6 +457,26 @@ class StaticTest(unittest.TestCase):
         # print(res)
         self.assertRegex(res, r"^((25[0-5]|(2[0-4]|1\d|[1-9]|)\d)\.?\b){4}$")
 
+    def testiso2dt(self):  # test secs2unit
+        tims = [
+            "2023-12-11T14:55:08.730000Z",
+            "2023-12-11T14:55:08.730000",
+            "2023-12-11T14:55:08.730Z",
+            "2023-12-11T14:55:08.730",
+            "2023-12-11T14:55:08",
+        ]
+        dts = [
+            "1702306508.73",
+            "1702306508.73",
+            "1702306508.73",
+            "1702306508.73",
+            "1702306508.0",
+        ]
+        for i, t in enumerate(tims):
+            res = isot2dt(t)
+            # print(res)
+            self.assertEqual(str(res), dts[i])
+
 
 if __name__ == "__main__":
     # import sys;sys.argv = ['', 'Test.testName']
